@@ -1,12 +1,12 @@
-# $Id: __init__.py 384 2006-08-04 00:39:44Z jonojono $
+# $Id: __init__.py 63 2010-03-26 02:20:33Z dugsong $
 
 """fast, simple packet creation and parsing."""
 
 __author__ = 'Dug Song <dugsong@monkey.org>'
 __copyright__ = 'Copyright (c) 2004 Dug Song'
 __license__ = 'BSD'
-__url__ = 'http://monkey.org/~dugsong/dpkt/'
-__version__ = '1.6'
+__url__ = 'http://dpkt.googlecode.com/'
+__version__ = '1.7'
 
 from dpkt import *
 
@@ -29,6 +29,7 @@ import hsrp
 import http
 import icmp
 import icmp6
+import ieee80211
 import igmp
 import ip
 import ip6
@@ -45,10 +46,13 @@ import pmap
 import ppp
 import pppoe
 import qq
+import radiotap
 import radius
+import rfb
 import rip
 import rpc
 import rtp
+import rx
 import sccp
 import sctp
 import sip
